@@ -347,11 +347,12 @@ import logging
 from landscape.lib.hashlib import md5
 
 from twisted.internet.defer import Deferred, succeed
-from twisted.python.compat import _PY3
+from landscape.lib.compat import _PY3
 
+from landscape.lib.backoff import ExponentialBackoff
 from landscape.lib.fetch import HTTPCodeError, PyCurlError
 from landscape.lib.format import format_delta
-from landscape.lib.message import got_next_expected, ANCIENT
+from landscape.lib.message import got_next_expected, RESYNC
 from landscape.lib.versioning import is_version_higher, sort_versions
 
 from landscape import DEFAULT_SERVER_API, SERVER_API, CLIENT_API
@@ -397,6 +398,7 @@ class MessageExchange(object):
         self._exchange_interval = config.exchange_interval
         self._urgent_exchange_interval = config.urgent_exchange_interval
         self._max_messages = max_messages
+        self._max_log_text_bytes = 100000  # 100KB
         self._notification_id = None
         self._exchange_id = None
         self._exchanging = False
@@ -406,6 +408,7 @@ class MessageExchange(object):
         self._message_handlers = {}
         self._exchange_store = exchange_store
         self._stopped = False
+        self._backoff_counter = ExponentialBackoff(300, 7200)  # 5 to 120 min
 
         self.register_message("accepted-types", self._handle_accepted_types)
         self.register_message("resynchronize", self._handle_resynchronize)
@@ -436,6 +439,20 @@ class MessageExchange(object):
 
         return result
 
+    def truncate_message_field(self, field, message):
+        """
+        Truncates message field value based on length
+        """
+        if field in message:
+            value = message[field]
+            if isinstance(value, str):
+                # Note this is an approximation based on 1 byte chars
+                max_bytes = self._max_log_text_bytes
+                if len(value) > max_bytes:
+                    value = value[:max_bytes]
+                    value += '...MESSAGE TRUNCATED DUE TO SIZE'
+                    message[field] = value
+
     def send(self, message, urgent=False):
         """Include a message to be sent in an exchange.
 
@@ -451,6 +468,10 @@ class MessageExchange(object):
                 % message.get('operation-id'))
             return None
 
+        # These fields sometimes have really long output we need to trim
+        self.truncate_message_field('err', message)
+        self.truncate_message_field('result-text', message)
+
         if "timestamp" not in message:
             message["timestamp"] = int(self._reactor.time())
         message_id = self._message_store.add(message)
@@ -567,6 +588,7 @@ class MessageExchange(object):
                     self._urgent_exchange = False
                 self._handle_result(payload, result)
                 self._message_store.record_success(int(self._reactor.time()))
+                self._backoff_counter.decrease()
             else:
                 self._reactor.fire("exchange-failed")
                 logging.info("Message exchange failed.")
@@ -586,6 +608,20 @@ class MessageExchange(object):
                     self.exchange()
                     return
 
+            if isinstance(error, HTTPCodeError):
+                if error.http_code == 429 or (500 <= error.http_code <= 599):
+                    # We add an exponentially increasing delay ("backoff") if
+                    # the server is overloaded to decrease load. We assume that
+                    # any server backend error is deserving backoff, including
+                    # 429 which is sent from the server on purpose to trigger
+                    # the backoff. Whether the server is down or overloaded
+                    # (503), has a server bug crashing the response (500),
+                    # backing off should have no ill effect and help the
+                    # service to recover. Client-configuration related errors
+                    # (501, 505) are probably fine to throttle too as a higher
+                    # rate won't help resolve them
+                    self._backoff_counter.increase()
+
             ssl_error = False
             if isinstance(error, PyCurlError) and error.error_code == 60:
                 # The error returned is an SSL error, most likely the server
@@ -642,6 +678,11 @@ class MessageExchange(object):
                 interval = self._config.urgent_exchange_interval
             else:
                 interval = self._config.exchange_interval
+            backoff_delay = self._backoff_counter.get_random_delay()
+            if backoff_delay:
+                logging.warning("Server is busy. Backing off client for {} "
+                                "seconds".format(backoff_delay))
+                interval += backoff_delay
 
             if self._notification_id is not None:
                 self._reactor.cancel_call(self._notification_id)
@@ -746,9 +787,9 @@ class MessageExchange(object):
             next_expected += len(payload["messages"])
 
         message_store_state = got_next_expected(message_store, next_expected)
-        if message_store_state == ANCIENT:
-            # The server has probably lost some data we sent it. The
-            # slate has been wiped clean (by got_next_expected), now
+        if message_store_state == RESYNC:
+            # The server has probably lost some data we sent it. Or next
+            # expected is too high so the sequences are out of sync. Now
             # let's fire an event to tell all the plugins that they
             # ought to generate new messages so the server gets some
             # up-to-date data.
@@ -800,8 +841,7 @@ class MessageExchange(object):
             # actually expect it to be a string. Some unit tests set it to
             # a regular string (since there is no difference between strings
             # and bytes in Python 2), so we check the type before converting.
-            if _PY3 and isinstance(message["type"], bytes):
-                message["type"] = message["type"].decode("ascii")
+            message["type"] = maybe_bytes(message["type"])
             self.handle_message(message)
             sequence += 1
             message_store.set_server_sequence(sequence)
@@ -843,8 +883,9 @@ class MessageExchange(object):
 
         self._reactor.fire("message", message)
         # This has plan interference! but whatever.
-        if message["type"] in self._message_handlers:
-            for handler in self._message_handlers[message["type"]]:
+        message_type = maybe_bytes(message["type"])
+        if message_type in self._message_handlers:
+            for handler in self._message_handlers[message_type]:
                 handler(message)
 
     def register_client_accepted_message_type(self, type):
@@ -866,3 +907,10 @@ def get_accepted_types_diff(old_types, new_types):
     diff.extend(["%s" % type for type in stable_types])
     diff.extend(["-%s" % type for type in removed_types])
     return " ".join(diff)
+
+
+def maybe_bytes(thing):
+    """Return a py3 ascii string from maybe py2 bytes."""
+    if _PY3 and isinstance(thing, bytes):
+        return thing.decode("ascii")
+    return thing
