@@ -145,6 +145,50 @@ class MessageExchangeTest(LandscapeTest):
         self.mstore.add_pending_offset(1)
         self.assertFalse(self.mstore.is_pending(message_id))
 
+    def test_send_big_message_trimmed_err(self):
+        """
+        When package reporter sends error, message is trimmed if too long
+        """
+        self.mstore.set_accepted_types(["package-reporter-result"])
+        self.exchanger._max_log_text_bytes = 5
+        self.exchanger.send({"type": "package-reporter-result", "err": "E"*10,
+                             "code": 0})
+        self.exchanger.exchange()
+        self.assertEqual(len(self.transport.payloads), 1)
+        messages = self.transport.payloads[0]["messages"]
+        self.assertIn('TRUNCATED', messages[0]['err'])
+        self.assertIn('EEEEE', messages[0]['err'])
+        self.assertNotIn('EEEEEE', messages[0]['err'])
+
+    def test_send_big_message_trimmed_result(self):
+        """
+        When an activity sends result log, message is trimmed if too long
+        """
+        self.mstore.set_accepted_types(["operation-result"])
+        self.exchanger._max_log_text_bytes = 5
+        self.exchanger.send({"type": "operation-result", "result-text": "E"*10,
+                             "code": 0, "status": 0, "operation-id": 0})
+        self.exchanger.exchange()
+        self.assertEqual(len(self.transport.payloads), 1)
+        messages = self.transport.payloads[0]["messages"]
+        self.assertIn('TRUNCATED', messages[0]['result-text'])
+        self.assertIn('EEEEE', messages[0]['result-text'])
+        self.assertNotIn('EEEEEE', messages[0]['result-text'])
+
+    def test_send_small_message_not_trimmed(self):
+        """
+        If message is below length, nothing should happen
+        """
+        self.mstore.set_accepted_types(["package-reporter-result"])
+        self.exchanger._max_log_text_bytes = 4
+        self.exchanger.send({"type": "package-reporter-result", "err": "E"*4,
+                             "code": 0})
+        self.exchanger.exchange()
+        self.assertEqual(len(self.transport.payloads), 1)
+        messages = self.transport.payloads[0]["messages"]
+        self.assertNotIn('TRUNCATED', messages[0]['err'])
+        self.assertIn('EEEE', messages[0]['err'])
+
     def test_wb_include_accepted_types(self):
         """
         Every payload from the client needs to specify an ID which
@@ -324,6 +368,88 @@ class MessageExchangeTest(LandscapeTest):
         self.assertEqual(payload["sequence"], 1)
         self.assertEqual(payload["next-expected-sequence"], 0)
 
+    @mock.patch("landscape.client.broker.store.MessageStore"
+                ".delete_old_messages")
+    def test_pending_offset_when_next_expected_too_high(self,
+                                                        mock_rm_all_messages):
+        '''
+        When next expected sequence received from server is too high, then the
+        pending offset should reset to zero. This will cause the client to
+        resend the pending messages.
+        '''
+
+        self.mstore.set_accepted_types(["data"])
+        self.mstore.add({"type": "data", "data": 0})
+        self.mstore.add({"type": "data", "data": 1})
+
+        self.exchanger.exchange()
+
+        self.assertEqual(self.mstore.get_pending_offset(), 2)
+
+        self.mstore.add({"type": "data", "data": 2})
+
+        self.transport.next_expected_sequence = 100
+
+        # Confirm pending offset is reset so that messages are sent again
+        self.exchanger.exchange()
+        self.assertEqual(self.mstore.get_pending_offset(), 0)
+
+        # This function flushes the queue, otherwise an offset of 0 will resend
+        # previous messages that were already successful
+        self.assertTrue(mock_rm_all_messages.called)
+
+    def test_payloads_when_next_expected_too_high(self):
+        '''
+        When next expected sequence received from server is too high, then the
+        current messages should get sent again since we don't have confirmation
+        that the server received it. Also previous messages should not get
+        repeated.
+        '''
+
+        self.mstore.set_accepted_types(["data"])
+
+        message0 = {"type": "data", "data": 0}
+        self.mstore.add(message0)
+        self.exchanger.exchange()
+
+        message1 = {"type": "data", "data": 1}
+        message2 = {"type": "data", "data": 2}
+        self.mstore.add(message1)
+        self.mstore.add(message2)
+
+        self.transport.next_expected_sequence = 100
+        self.exchanger.exchange()  # Resync
+        self.exchanger.exchange()  # Resend
+
+        # Confirm messages is not empty which was the original bug
+        last_messages = self.transport.payloads[-1]["messages"]
+        self.assertTrue(last_messages)
+
+        # Confirm earlier messages are not resent
+        self.assertNotIn(message0["data"],
+                         [m["data"] for m in last_messages])
+
+        # Confirm contents of payload
+        self.assertEqual([message1, message2], last_messages)
+
+    def test_resync_when_next_expected_too_high(self):
+        '''
+        When next expected sequence received from the server is too high, then
+        a resynchronize should happen
+        '''
+
+        self.mstore.set_accepted_types(["empty", "resynchronize"])
+        self.mstore.add({"type": "empty"})
+        self.exchanger.exchange()
+
+        self.transport.next_expected_sequence = 100
+
+        self.reactor.call_on("resynchronize-clients", lambda scope=None: None)
+
+        self.exchanger.exchange()
+        self.assertMessage(self.mstore.get_pending_messages()[-1],
+                           {"type": "resynchronize"})
+
     def test_start_with_urgent_exchange(self):
         """
         Immediately after registration, an urgent exchange should be scheduled.
@@ -1088,6 +1214,64 @@ class MessageExchangeTest(LandscapeTest):
         self.exchanger.exchange()
         self.assertEqual(b"3.2", self.mstore.get_server_api())
 
+    def test_500_backoff(self):
+        """
+        If we get a server error then the exponential backoff is triggered
+        """
+        self.config.urgent_exchange_interval = 10
+        self.exchanger._backoff_counter._start_delay = 300
+        self.exchanger._backoff_counter._max_delay = 1000
+        self.transport.responses.append(HTTPCodeError(503, ""))
+        self.exchanger.schedule_exchange(urgent=True)
+        self.reactor.advance(50)
+        self.assertEqual(len(self.transport.payloads), 1)
+        self.reactor.advance(400)
+        self.assertEqual(len(self.transport.payloads), 2)
+
+    def test_429_backoff(self):
+        """
+        HTTP error 429 should also trigger backoff
+        """
+        self.config.urgent_exchange_interval = 10
+        self.exchanger._backoff_counter._start_delay = 300
+        self.exchanger._backoff_counter._max_delay = 1000
+        self.transport.responses.append(HTTPCodeError(429, ""))
+        self.exchanger.schedule_exchange(urgent=True)
+        self.reactor.advance(50)
+        self.assertEqual(len(self.transport.payloads), 1)
+
+    def test_backoff_reset_after_success(self):
+        """
+        If we get a success after a 500 error then backoff should be zero
+        """
+        self.config.urgent_exchange_interval = 10
+        self.exchanger._backoff_counter._start_delay = 300
+        self.exchanger._backoff_counter._max_delay = 1000
+        self.transport.responses.append(HTTPCodeError(500, ""))
+        self.exchanger.schedule_exchange(urgent=True)
+        self.reactor.advance(50)
+
+        # Confirm it's not zero after the error
+        self.assertTrue(self.exchanger._backoff_counter.get_random_delay())
+
+        server_message = [{"type": "type-R", "whatever": 5678}]
+        self.transport.responses.append(server_message)
+        self.exchanger.schedule_exchange(urgent=True)
+        self.reactor.advance(500)
+
+        # Confirm it is zero after the success
+        self.assertFalse(self.exchanger._backoff_counter.get_random_delay())
+
+    def test_400_no_backoff(self):
+        """
+        If we get a 400 error then the backoff should not be triggered
+        """
+        self.config.urgent_exchange_interval = 10
+        self.transport.responses.append(HTTPCodeError(400, ""))
+        self.exchanger.schedule_exchange(urgent=True)
+        self.reactor.advance(20)
+        self.assertEqual(len(self.transport.payloads), 2)
+
 
 class AcceptedTypesMessageExchangeTest(LandscapeTest):
 
