@@ -3,7 +3,7 @@ import logging
 import socket
 import mock
 
-from twisted.python.compat import _PY3
+from landscape.lib.compat import _PY3
 
 from landscape.client.broker.registration import RegistrationError, Identity
 from landscape.client.tests.helpers import LandscapeTest
@@ -90,7 +90,7 @@ class RegistrationHandlerTest(RegistrationHandlerTestBase):
         and insecure ids even if no requests were sent.
         """
         self.exchanger.handle_message(
-            {"type": "set-id", "id": "abc", "insecure-id": "def"})
+            {"type": b"set-id", "id": b"abc", "insecure-id": b"def"})
         self.assertEqual(self.identity.secure_id, "abc")
         self.assertEqual(self.identity.insecure_id, "def")
 
@@ -101,29 +101,58 @@ class RegistrationHandlerTest(RegistrationHandlerTestBase):
         """
         reactor_fire_mock = self.reactor.fire = mock.Mock()
         self.exchanger.handle_message(
-            {"type": "set-id", "id": "abc", "insecure-id": "def"})
+            {"type": b"set-id", "id": b"abc", "insecure-id": b"def"})
         reactor_fire_mock.assert_any_call("registration-done")
 
     def test_unknown_id(self):
         self.identity.secure_id = "old_id"
         self.identity.insecure_id = "old_id"
         self.mstore.set_accepted_types(["register"])
-        self.exchanger.handle_message({"type": "unknown-id"})
+        self.exchanger.handle_message({"type": b"unknown-id"})
         self.assertEqual(self.identity.secure_id, None)
         self.assertEqual(self.identity.insecure_id, None)
 
     def test_unknown_id_with_clone(self):
         """
         If the server reports us that we are a clone of another computer, then
-        set our computer's title accordingly.
+        make sure we handle it
         """
         self.config.computer_title = "Wu"
         self.mstore.set_accepted_types(["register"])
-        self.exchanger.handle_message({"type": "unknown-id", "clone-of": "Wu"})
-        self.assertEqual("Wu (clone)", self.config.computer_title)
+        self.exchanger.handle_message(
+            {"type": b"unknown-id", "clone-of": "Wu"})
         self.assertIn("Client is clone of computer Wu",
                       self.logfile.getvalue())
 
+    def test_clone_secure_id_saved(self):
+        """
+        Make sure that secure id is saved when theres a clone and existing
+        value is cleared out
+        """
+        secure_id = "foo"
+        self.identity.secure_id = secure_id
+        self.config.computer_title = "Wu"
+        self.mstore.set_accepted_types(["register"])
+        self.exchanger.handle_message(
+            {"type": b"unknown-id", "clone-of": "Wu"})
+        self.assertEqual(self.handler._clone_secure_id, secure_id)
+        self.assertIsNone(self.identity.secure_id)
+
+    def test_clone_id_in_message(self):
+        """
+        Make sure that the clone id is present in the registration message
+        """
+        secure_id = "foo"
+        self.identity.secure_id = secure_id
+        self.config.computer_title = "Wu"
+        self.mstore.set_accepted_types(["register"])
+        self.mstore.set_server_api(b"3.3")  # Note this is only for later api
+        self.exchanger.handle_message(
+            {"type": b"unknown-id", "clone-of": "Wu"})
+        self.reactor.fire("pre-exchange")
+        messages = self.mstore.get_pending_messages()
+        self.assertEqual(messages[0]["clone_secure_id"], secure_id)
+
     def test_should_register(self):
         self.mstore.set_accepted_types(["register"])
         self.config.computer_title = "Computer Title"
@@ -366,7 +395,7 @@ class RegistrationHandlerTest(RegistrationHandlerTestBase):
         """
         reactor_fire_mock = self.reactor.fire = mock.Mock()
         self.exchanger.handle_message(
-            {"type": "registration", "info": "unknown-account"})
+            {"type": b"registration", "info": b"unknown-account"})
         reactor_fire_mock.assert_called_with(
             "registration-failed", reason="unknown-account")
 
@@ -378,7 +407,7 @@ class RegistrationHandlerTest(RegistrationHandlerTestBase):
         """
         reactor_fire_mock = self.reactor.fire = mock.Mock()
         self.exchanger.handle_message(
-            {"type": "registration", "info": "max-pending-computers"})
+            {"type": b"registration", "info": b"max-pending-computers"})
         reactor_fire_mock.assert_called_with(
             "registration-failed", reason="max-pending-computers")
 
@@ -389,7 +418,7 @@ class RegistrationHandlerTest(RegistrationHandlerTestBase):
         """
         reactor_fire_mock = self.reactor.fire = mock.Mock()
         self.exchanger.handle_message(
-            {"type": "registration", "info": "blah-blah"})
+            {"type": b"registration", "info": b"blah-blah"})
         for name, args, kwargs in reactor_fire_mock.mock_calls:
             self.assertNotEquals("registration-failed", args[0])
 
@@ -420,13 +449,13 @@ class RegistrationHandlerTest(RegistrationHandlerTestBase):
 
         # This should somehow callback the deferred.
         self.exchanger.handle_message(
-            {"type": "set-id", "id": "abc", "insecure-id": "def"})
+            {"type": b"set-id", "id": b"abc", "insecure-id": b"def"})
 
         self.assertEqual(calls, [1])
 
         # Doing it again to ensure that the deferred isn't called twice.
         self.exchanger.handle_message(
-            {"type": "set-id", "id": "abc", "insecure-id": "def"})
+            {"type": b"set-id", "id": b"abc", "insecure-id": b"def"})
 
         self.assertEqual(calls, [1])
 
@@ -448,7 +477,7 @@ class RegistrationHandlerTest(RegistrationHandlerTestBase):
 
         # This should somehow callback the deferred.
         self.exchanger.handle_message(
-            {"type": "set-id", "id": "abc", "insecure-id": "def"})
+            {"type": b"set-id", "id": b"abc", "insecure-id": b"def"})
 
         self.assertEqual(results, [None])
 
@@ -473,13 +502,13 @@ class RegistrationHandlerTest(RegistrationHandlerTestBase):
 
         # This should somehow callback the deferred.
         self.exchanger.handle_message(
-            {"type": "registration", "info": "unknown-account"})
+            {"type": b"registration", "info": b"unknown-account"})
 
         self.assertEqual(calls, [True])
 
         # Doing it again to ensure that the deferred isn't called twice.
         self.exchanger.handle_message(
-            {"type": "registration", "info": "unknown-account"})
+            {"type": b"registration", "info": b"unknown-account"})
 
         self.assertEqual(calls, [True])
 
@@ -505,13 +534,13 @@ class RegistrationHandlerTest(RegistrationHandlerTestBase):
         d.addErrback(add_call)
 
         self.exchanger.handle_message(
-            {"type": "registration", "info": "max-pending-computers"})
+            {"type": b"registration", "info": b"max-pending-computers"})
 
         self.assertEqual(calls, [True])
 
         # Doing it again to ensure that the deferred isn't called twice.
         self.exchanger.handle_message(
-            {"type": "registration", "info": "max-pending-computers"})
+            {"type": b"registration", "info": b"max-pending-computers"})
 
         self.assertEqual(calls, [True])
 
