@@ -7,14 +7,15 @@ for the C{landscape-config} script.
 from __future__ import print_function
 
 from functools import partial
-import base64
 import getpass
 import io
 import os
 import pwd
 import sys
+import textwrap
 
 from landscape.lib.compat import input
+from landscape.lib import base64
 
 from landscape.lib.tag import is_valid_tag
 
@@ -33,6 +34,9 @@ from landscape.client.broker.registration import Identity
 from landscape.client.broker.service import BrokerService
 
 
+EXIT_NOT_REGISTERED = 5
+
+
 class ConfigurationError(Exception):
     """Raised when required configuration values are missing."""
 
@@ -192,6 +196,11 @@ class LandscapeSetupConfiguration(BrokerConfiguration):
         parser.add_option("--init", action="store_true", default=False,
                           help="Set up the client directories structure "
                                "and exit.")
+        parser.add_option("--is-registered", action="store_true",
+                          help="Exit with code 0 (success) if client is "
+                               "registered else returns {}. Displays "
+                               "registration info."
+                               .format(EXIT_NOT_REGISTERED))
         return parser
 
 
@@ -513,7 +522,7 @@ def decode_base64_ssl_public_certificate(config):
     # WARNING: ssl_public_certificate is misnamed, it's not the key of the
     # certificate, but the actual certificate itself.
     if config.ssl_public_key and config.ssl_public_key.startswith("base64:"):
-        decoded_cert = base64.decodestring(
+        decoded_cert = base64.decodebytes(
             config.ssl_public_key[7:].encode("ascii"))
         config.ssl_public_key = store_public_key_data(
             config, decoded_cert)
@@ -759,6 +768,26 @@ def is_registered(config):
     return bool(identity.secure_id)
 
 
+def registration_info_text(config, registration_status):
+    '''
+    A simple output displaying whether the client is registered or not, the
+    account name, and config and data paths
+    '''
+
+    config_path = os.path.abspath(config._config_filename)
+
+    text = textwrap.dedent("""
+                           Registered:    {}
+                           Config Path:   {}
+                           Data Path      {}"""
+                           .format(registration_status, config_path,
+                                   config.data_path))
+    if registration_status:
+        text += '\nAccount Name:  {}'.format(config.account_name)
+
+    return text
+
+
 def main(args, print=print):
     """Interact with the user and the server to set up client configuration."""
 
@@ -769,6 +798,18 @@ def main(args, print=print):
         print_text(str(error), error=True)
         sys.exit(1)
 
+    if config.is_registered:
+
+        registration_status = is_registered(config)
+
+        info_text = registration_info_text(config, registration_status)
+        print(info_text)
+
+        if registration_status:
+            sys.exit(0)
+        else:
+            sys.exit(EXIT_NOT_REGISTERED)
+
     if os.getuid() != 0:
         sys.exit("landscape-config must be run as root.")
 
