@@ -2,6 +2,9 @@
 Extend the regular Twisted reactor with event-handling features.
 """
 from landscape.lib.reactor import EventHandlingReactor
+from landscape.client.lockfile import patch_lockfile
+
+patch_lockfile()
 
 
 class LandscapeReactor(EventHandlingReactor):
