@@ -16,9 +16,10 @@ def clean_fds():
     unwanted file descriptors from the invoking process.  Unfortunately, this
     is really common in unix!
     """
-    total_descriptors = min(4096, resource.getrlimit(resource.RLIMIT_NOFILE)[1])
+    rlimit_nofile = resource.getrlimit(resource.RLIMIT_NOFILE)[1]
+    total_descriptors = min(4096, rlimit_nofile)
     for fd in range(3, total_descriptors):
         try:
             os.close(fd)
-        except OSError, e:
+        except OSError:
             pass
