@@ -11,7 +11,7 @@ import errno
 import logging
 
 import netifaces
-from twisted.python.compat import long
+from landscape.lib.compat import long, _PY3
 
 __all__ = ["get_active_device_info", "get_network_traffic"]
 
@@ -35,32 +35,14 @@ def is_up(flags):
     return flags & 1
 
 
-def get_active_interfaces():
-    """Generator yields (active network interface name, address data) tuples.
+def is_active(ifaddresses):
+    """Checks if interface address data has an IP address
 
-    Address data is formatted exactly like L{netifaces.ifaddresses}, e.g.::
-
-        ('eth0', {
-            AF_LINK: [
-                {'addr': '...', 'broadcast': '...'}, ],
-            AF_INET: [
-                {'addr': '...', 'broadcast': '...', 'netmask': '...'},
-                {'addr': '...', 'broadcast': '...', 'netmask': '...'},
-                ...],
-            AF_INET6: [
-                {'addr': '...', 'netmask': '...'},
-                {'addr': '...', 'netmask': '...'},
-                ...], })
-
-    Interfaces with no IP address are ignored.
+    @param ifaddresses: a dict as returned by L{netifaces.ifaddresses}
     """
-    for interface in netifaces.interfaces():
-        ifaddresses = netifaces.ifaddresses(interface)
-        # Skip interfaces with no IPv4 or IPv6 addresses.
-        inet_addr = ifaddresses.get(netifaces.AF_INET, [{}])[0].get('addr')
-        inet6_addr = ifaddresses.get(netifaces.AF_INET6, [{}])[0].get('addr')
-        if inet_addr or inet6_addr:
-            yield interface, ifaddresses
+    inet_addr = ifaddresses.get(netifaces.AF_INET, [{}])[0].get('addr')
+    inet6_addr = ifaddresses.get(netifaces.AF_INET6, [{}])[0].get('addr')
+    return bool(inet_addr or inet6_addr)
 
 
 def get_ip_addresses(ifaddresses):
@@ -69,8 +51,7 @@ def get_ip_addresses(ifaddresses):
     Returns the same structure as L{ifaddresses}, but filtered to keep
     IP addresses only.
 
-    @param ifaddresses: a dict as returned by L{netifaces.ifaddresses} or
-        the address data in L{get_active_interfaces}'s output.
+    @param ifaddresses: a dict as returned by L{netifaces.ifaddresses}
     """
     results = {}
     if netifaces.AF_INET in ifaddresses:
@@ -88,8 +69,7 @@ def get_ip_addresses(ifaddresses):
 def get_broadcast_address(ifaddresses):
     """Return the broadcast address associated to an interface.
 
-    @param ifaddresses: a dict as returned by L{netifaces.ifaddresses} or
-        the address data in L{get_active_interfaces}'s output.
+    @param ifaddresses: a dict as returned by L{netifaces.ifaddresses}
     """
     return ifaddresses[netifaces.AF_INET][0].get('broadcast', '0.0.0.0')
 
@@ -97,8 +77,7 @@ def get_broadcast_address(ifaddresses):
 def get_netmask(ifaddresses):
     """Return the network mask associated to an interface.
 
-    @param ifaddresses: a dict as returned by L{netifaces.ifaddresses} or
-        the address data in L{get_active_interfaces}'s output.
+    @param ifaddresses: a dict as returned by L{netifaces.ifaddresses}
     """
     return ifaddresses[netifaces.AF_INET][0].get('netmask', '')
 
@@ -106,8 +85,7 @@ def get_netmask(ifaddresses):
 def get_ip_address(ifaddresses):
     """Return the first IPv4 address associated to the interface.
 
-    @param ifaddresses: a dict as returned by L{netifaces.ifaddresses} or
-        the address data in L{get_active_interfaces}'s output.
+    @param ifaddresses: a dict as returned by L{netifaces.ifaddresses}
     """
     return ifaddresses[netifaces.AF_INET][0]['addr']
 
@@ -118,8 +96,7 @@ def get_mac_address(ifaddresses):
     ie. six colon separated groups of two hexadecimal digits, if available;
     otherwise an empty string.
 
-    @param ifaddresses: a dict as returned by L{netifaces.ifaddresses} or
-        the address data in L{get_active_interfaces}'s output.
+    @param ifaddresses: a dict as returned by L{netifaces.ifaddresses}
     """
     if netifaces.AF_LINK in ifaddresses:
         return ifaddresses[netifaces.AF_LINK][0].get('addr', '')
@@ -138,51 +115,104 @@ def get_flags(sock, interface):
     return struct.unpack("H", data[16:18])[0]
 
 
-def get_active_device_info(skipped_interfaces=("lo",),
-                           skip_vlan=True, skip_alias=True, extended=False):
+def get_default_interfaces():
     """
-    Returns a dictionary containing information on each active network
-    interface present on a machine.
+    Returns a list of interfaces with default routes
+    """
+    default_table = netifaces.gateways()['default']
+    interfaces = [gateway[1] for gateway in default_table.values()]
+    return interfaces
+
+
+def get_filtered_if_info(filters=(), extended=False):
+    """
+    Returns a dictionary containing info on each active network
+    interface that passes all `filters`.
+
+    A filter is a callable that returns True if the interface should be
+    skipped.
     """
     results = []
+
     try:
         sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM,
                              socket.IPPROTO_IP)
-        for interface, ifaddresses in get_active_interfaces():
-            if interface in skipped_interfaces:
+
+        for interface in netifaces.interfaces():
+            if any(f(interface) for f in filters):
                 continue
-            if skip_vlan and "." in interface:
+
+            ifaddresses = netifaces.ifaddresses(interface)
+            if not is_active(ifaddresses):
                 continue
-            if skip_alias and ":" in interface:
-                continue
-            flags = get_flags(sock, interface.encode())
+
+            ifencoded = interface.encode()
+            flags = get_flags(sock, ifencoded)
             if not is_up(flags):
                 continue
-            interface_info = {"interface": interface}
-            interface_info["flags"] = flags
-            speed, duplex = get_network_interface_speed(
-                sock, interface.encode())
-            interface_info["speed"] = speed
-            interface_info["duplex"] = duplex
+
             ip_addresses = get_ip_addresses(ifaddresses)
+            if not extended and netifaces.AF_INET not in ip_addresses:
+                # Skip interfaces with no IPv4 addr unless extended to
+                # keep backwards compatibility with single-IPv4 addr
+                # support.
+                continue
+
+            ifinfo = {"interface": interface}
+            ifinfo["flags"] = flags
+            ifinfo["speed"], ifinfo["duplex"] = get_network_interface_speed(
+                sock, ifencoded)
+
             if extended:
-                interface_info["ip_addresses"] = ip_addresses
+                ifinfo["ip_addresses"] = ip_addresses
+
             if netifaces.AF_INET in ip_addresses:
-                interface_info["ip_address"] = get_ip_address(ifaddresses)
-                interface_info["mac_address"] = get_mac_address(ifaddresses)
-                interface_info["broadcast_address"] = get_broadcast_address(
+                ifinfo["ip_address"] = get_ip_address(ifaddresses)
+                ifinfo["mac_address"] = get_mac_address(ifaddresses)
+                ifinfo["broadcast_address"] = get_broadcast_address(
                     ifaddresses)
-                interface_info["netmask"] = get_netmask(ifaddresses)
-            # Skip interfaces with no IPv4 address in non-extended mode
-            # to keep backwards compatibility with single-IPv4 addr support.
-            if netifaces.AF_INET in ip_addresses or extended:
-                results.append(interface_info)
+                ifinfo["netmask"] = get_netmask(ifaddresses)
+
+            results.append(ifinfo)
     finally:
-        del sock
+        sock.close()
 
     return results
 
 
+def get_active_device_info(skipped_interfaces=("lo",),
+                           skip_vlan=True, skip_alias=True,
+                           extended=False, default_only=False):
+    def filter_local(interface):
+        return interface in skipped_interfaces
+
+    def filter_vlan(interface):
+        return "." in interface
+
+    def filter_alias(interface):
+        return ":" in interface
+
+    # Get default interfaces here because it could be expensive and
+    # there's no reason to do it more than once.
+    default_ifs = get_default_interfaces()
+
+    def filter_default(interface):
+        return default_only and interface not in default_ifs
+
+    # Tap interfaces can be extremely numerous, slowing us down
+    # significantly.
+    def filter_tap(interface):
+        return interface.startswith("tap")
+
+    return get_filtered_if_info(filters=(
+        filter_tap,
+        filter_local,
+        filter_vlan,
+        filter_alias,
+        filter_default,
+    ), extended=extended)
+
+
 def get_network_traffic(source_file="/proc/net/dev"):
     """
     Retrieves an array of information regarding the network activity per
@@ -246,13 +276,16 @@ def get_network_interface_speed(sock, interface_name):
     speed = -1
     try:
         fcntl.ioctl(sock, SIOCETHTOOL, packed)  # Status ioctl() call
-        res = status_cmd.tostring()
+        if _PY3:
+            res = status_cmd.tobytes()
+        else:
+            res = status_cmd.tostring()
         speed, duplex = struct.unpack("12xHB28x", res)
-    except IOError as e:
+    except (IOError, OSError) as e:
         if e.errno == errno.EPERM:
-            logging.warn("Could not determine network interface speed, "
-                         "operation not permitted.")
-        elif e.errno != errno.EOPNOTSUPP:
+            logging.warning("Could not determine network interface speed, "
+                            "operation not permitted.")
+        elif e.errno != errno.EOPNOTSUPP and e.errno != errno.EINVAL:
             raise e
         speed = -1
         duplex = False
