@@ -1,7 +1,7 @@
 import socket
 import unittest
 
-from mock import patch, ANY, mock_open
+from unittest.mock import ANY, DEFAULT, patch, mock_open
 from netifaces import (
     AF_INET,
     AF_INET6,
@@ -14,8 +14,8 @@ from subprocess import Popen, PIPE
 
 from landscape.lib import testing
 from landscape.lib.network import (
-    get_network_traffic, get_active_device_info, get_active_interfaces,
-    get_fqdn, get_network_interface_speed, is_up)
+    get_active_device_info, get_filtered_if_info, get_fqdn,
+    get_network_interface_speed, get_network_traffic, is_up)
 
 
 class BaseTestCase(testing.HelperTestCase, unittest.TestCase):
@@ -148,31 +148,60 @@ class NetworkInfoTest(BaseTestCase):
                 'duplex': True,
                 'ip_addresses': {AF_INET6: [{'addr': '2001::1'}]}}])
 
+    @patch("landscape.lib.network.get_default_interfaces")
+    @patch("landscape.lib.network.get_network_interface_speed")
+    @patch("landscape.lib.network.get_flags")
+    @patch("landscape.lib.network.netifaces.ifaddresses")
+    @patch("landscape.lib.network.netifaces.interfaces")
+    def test_default_only_interface(
+            self, mock_interfaces, mock_ifaddresses, mock_get_flags,
+            mock_get_network_interface_speed, mock_get_default_interfaces):
+        default_iface = "test_iface"
+        mock_get_default_interfaces.return_value = [default_iface]
+        mock_get_network_interface_speed.return_value = (100, True)
+        mock_get_flags.return_value = 4163
+        mock_interfaces.return_value = [default_iface]
+        mock_ifaddresses.return_value = {AF_INET: [{"addr": "192.168.0.50"}]}
+        device_info = get_active_device_info(extended=False, default_only=True)
+        interfaces = [i["interface"] for i in device_info]
+        self.assertIn(default_iface, interfaces)
+        self.assertEqual(len(interfaces), 1)
+
     def test_skip_loopback(self):
         """The C{lo} interface is not reported by L{get_active_device_info}."""
         device_info = get_active_device_info()
         interfaces = [i["interface"] for i in device_info]
         self.assertNotIn("lo", interfaces)
 
-    @patch("landscape.lib.network.get_active_interfaces")
-    def test_skip_vlan(self, mock_get_active_interfaces):
+    @patch("landscape.lib.network.netifaces.interfaces")
+    def test_skip_vlan(self, mock_interfaces):
         """VLAN interfaces are not reported by L{get_active_device_info}."""
-        mock_get_active_interfaces.side_effect = lambda: (
-            list(get_active_interfaces()) + [("eth0.1", {})])
+        mock_interfaces.side_effect = lambda: (
+            _interfaces() + ["eth0.1"])
         device_info = get_active_device_info()
-        self.assertTrue(mock_get_active_interfaces.called)
         interfaces = [i["interface"] for i in device_info]
         self.assertNotIn("eth0.1", interfaces)
 
-    @patch("landscape.lib.network.get_active_interfaces")
-    def test_skip_alias(self, mock_get_active_interfaces):
+    @patch("landscape.lib.network.netifaces.interfaces")
+    def test_skip_alias(self, mock_interfaces):
         """Interface aliases are not reported by L{get_active_device_info}."""
-        mock_get_active_interfaces.side_effect = lambda: (
-            list(get_active_interfaces()) + [("eth0:foo", {})])
+        mock_interfaces.side_effect = lambda: (
+            _interfaces() + ["eth0:foo"])
         device_info = get_active_device_info()
         interfaces = [i["interface"] for i in device_info]
         self.assertNotIn("eth0:foo", interfaces)
 
+    @patch("landscape.lib.network.netifaces.ifaddresses")
+    @patch("landscape.lib.network.netifaces.interfaces")
+    def test_no_extra_netifaces_calls(self, mock_interfaces, mock_ifaddresses):
+        """
+        Make sure filtered out interfaces aren't used in netiface calls due to
+        their impact on sysinfo/login time with a large amount of interfaces.
+        """
+        mock_interfaces.return_value = ["eth0:foo"]
+        get_active_device_info()
+        assert not mock_ifaddresses.called
+
     @patch("landscape.lib.network.netifaces.ifaddresses")
     @patch("landscape.lib.network.netifaces.interfaces")
     def test_skip_iface_with_no_addr(self, mock_interfaces, mock_ifaddresses):
@@ -283,6 +312,53 @@ class NetworkInfoTest(BaseTestCase):
         self.assertFalse(is_up(2 + 64 + 4096))
         self.assertFalse(is_up(0b11111111111110))
 
+    def test_get_filtered_if_info(self):
+        def filter_tap(interface):
+            return interface.startswith("tap")
+
+        with patch.multiple(
+                "landscape.lib.network",
+                get_flags=DEFAULT,
+                get_network_interface_speed=DEFAULT,
+                netifaces=DEFAULT,
+        ) as mocks:
+            mocks["netifaces"].interfaces.return_value = [
+                "tap0123",
+                "test_iface",
+                "tap4567",
+                "test_iface2",
+            ]
+            mocks["get_flags"].return_value = 4163
+            mocks["get_network_interface_speed"].return_value = (100, True)
+            device_info = get_filtered_if_info(filters=(filter_tap,),
+                                               extended=True)
+
+        self.assertEqual(len(device_info), 2)
+        self.assertTrue(all("tap" not in i["interface"] for i in device_info))
+
+    def test_get_active_device_info_filtered_taps(self):
+        """
+        Tests that tap network interfaces are filtered out.
+        """
+        with patch.multiple(
+                "landscape.lib.network",
+                get_flags=DEFAULT,
+                get_network_interface_speed=DEFAULT,
+                netifaces=DEFAULT,
+        ) as mocks:
+            mocks["netifaces"].interfaces.return_value = [
+                "tap0123",
+                "test_iface",
+                "tap4567",
+                "test_iface2",
+            ]
+            mocks["get_flags"].return_value = 4163
+            mocks["get_network_interface_speed"].return_value = (100, True)
+            device_info = get_active_device_info(extended=True)
+
+        self.assertEqual(len(device_info), 2)
+        self.assertTrue(all("tap" not in i["interface"] for i in device_info))
+
 
 # exact output of cat /proc/net/dev snapshot with line continuations for pep8
 test_proc_net_dev_output = """\
@@ -370,6 +446,7 @@ class NetworkInterfaceSpeedTest(BaseTestCase):
         mock_unpack.assert_called_with("12xHB28x", ANY)
 
         self.assertEqual((100, False), result)
+        sock.close()
 
     @patch("struct.unpack")
     @patch("fcntl.ioctl")
@@ -389,6 +466,7 @@ class NetworkInterfaceSpeedTest(BaseTestCase):
         mock_unpack.assert_called_with("12xHB28x", ANY)
 
         self.assertEqual((0, False), result)
+        sock.close()
 
     @patch("fcntl.ioctl")
     def test_get_network_interface_speed_not_supported(self, mock_ioctl):
@@ -411,6 +489,7 @@ class NetworkInterfaceSpeedTest(BaseTestCase):
         mock_ioctl.assert_called_with(ANY, ANY, ANY)
 
         self.assertEqual((-1, False), result)
+        sock.close()
 
     @patch("fcntl.ioctl")
     def test_get_network_interface_speed_not_permitted(self, mock_ioctl):
@@ -433,6 +512,7 @@ class NetworkInterfaceSpeedTest(BaseTestCase):
         mock_ioctl.assert_called_with(ANY, ANY, ANY)
 
         self.assertEqual((-1, False), result)
+        sock.close()
 
     @patch("fcntl.ioctl")
     def test_get_network_interface_speed_other_io_error(self, mock_ioctl):
@@ -450,3 +530,4 @@ class NetworkInterfaceSpeedTest(BaseTestCase):
         mock_ioctl.side_effect = theerror
 
         self.assertRaises(IOError, get_network_interface_speed, sock, b"eth0")
+        sock.close()
