@@ -19,7 +19,7 @@ __all__ = [
     "NETWORK_DEVICE", "NETWORK_ACTIVITY",
     "REBOOT_REQUIRED_INFO", "UPDATE_MANAGER_INFO", "CPU_USAGE",
     "CEPH_USAGE", "SWIFT_USAGE", "SWIFT_DEVICE_INFO", "KEYSTONE_TOKEN",
-    "JUJU_UNITS_INFO", "CLOUD_METADATA",
+    "JUJU_UNITS_INFO", "CLOUD_METADATA", "COMPUTER_TAGS", "UBUNTU_PRO_INFO",
     ]
 
 
@@ -219,10 +219,13 @@ REGISTER_3_3 = Message(
      "juju-info": KeyDict({"environment-uuid": Unicode(),
                            "api-addresses": List(Unicode()),
                            "machine-id": Unicode()}),
-     "access_group": Unicode()},
+     "access_group": Unicode(),
+     "clone_secure_id": Any(Unicode(), Constant(None)),
+     "ubuntu_pro_info": Unicode()},
     api=b"3.3",
     optional=["registration_password", "hostname", "tags", "vm-info",
-              "container-info", "access_group", "juju-info"])
+              "container-info", "access_group", "juju-info",
+              "clone_secure_id", "ubuntu_pro_info"])
 
 
 # XXX The register-provisioned-machine message is obsolete, it's kept around
@@ -367,13 +370,16 @@ PACKAGES = Message(
      "locked": package_ids_or_ranges,
      "autoremovable": package_ids_or_ranges,
      "not-autoremovable": package_ids_or_ranges,
+     "security": package_ids_or_ranges,
      "not-installed": package_ids_or_ranges,
      "not-available": package_ids_or_ranges,
      "not-available-upgrades": package_ids_or_ranges,
-     "not-locked": package_ids_or_ranges},
+     "not-locked": package_ids_or_ranges,
+     "not-security": package_ids_or_ranges},
     optional=["installed", "available", "available-upgrades", "locked",
               "not-available", "not-installed", "not-available-upgrades",
-              "not-locked", "autoremovable", "not-autoremovable"])
+              "not-locked", "autoremovable", "not-autoremovable", "security",
+              "not-security"])
 
 package_locks = List(Tuple(Unicode(), Unicode(), Unicode()))
 PACKAGE_LOCKS = Message(
@@ -501,6 +507,13 @@ NETWORK_ACTIVITY = Message(
 
 UPDATE_MANAGER_INFO = Message("update-manager-info", {"prompt": Unicode()})
 
+COMPUTER_TAGS = Message(
+    "computer-tags",
+    {"tags": Any(Unicode(), Constant(None))})
+
+UBUNTU_PRO_INFO = Message(
+    "ubuntu-pro-info",
+    {"ubuntu-pro-info": Unicode()})
 
 message_schemas = (
     ACTIVE_PROCESS_INFO, COMPUTER_UPTIME, CLIENT_UPTIME,
@@ -515,4 +528,4 @@ message_schemas = (
     NETWORK_DEVICE, NETWORK_ACTIVITY,
     REBOOT_REQUIRED_INFO, UPDATE_MANAGER_INFO, CPU_USAGE,
     CEPH_USAGE, SWIFT_USAGE, SWIFT_DEVICE_INFO, KEYSTONE_TOKEN,
-    JUJU_UNITS_INFO, CLOUD_METADATA)
+    JUJU_UNITS_INFO, CLOUD_METADATA, COMPUTER_TAGS, UBUNTU_PRO_INFO)
